==> nextcloud-11.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/settings/l10n/ka_GE.js <==
OC.L10N.register(
    "settings",
    {
    "Authentication error" : "ავთენტიფიკაციის შეცდომა",
    "Invalid request" : "არასწორი მოთხოვნა",
    "Email saved" : "იმეილი შენახულია",
    "Couldn't update app." : "ვერ მოხერხდა აპლიკაციის განახლება.",
    "Email sent" : "იმეილი გაიგზავნა",
    "All" : "ყველა",
    "Disable" : "გამორთვა",
    "Enable" : "ჩართვა",
    "Updating...." : "მიმდინარეობს განახლება....",
    "Error while updating app" : "შეცდომა აპლიკაციის განახლების დროს",
    "Updated" : "განახლებულია",
    "Delete" : "წაშლა",
    "Groups" : "ჯგუფები",
    "undo" : "დაბრუნება",
    "never" : "არასდროს",
    "A valid username must be provided" : "უნდა მიუთითოთ არსებული მომხმარებლის სახელი",
    "A valid password must be provided" : "უნდა მიუთითოთ არსებული პაროლი",
    "__language_name__" : "ქართული",
    "Unlimited" : "ულიმიტო",
    "None" : "არა",
    "Login" : "ლოგინი",
    "Encryption" : "ენკრიპცია",
    "Server address" : "სერვერის მისამართი",
    "Port" : "პორტი",
    "Credentials" : "იუზერ/პაროლი",
    "Cron" : "Cron–ი",
    "Execute one task with each page loaded" : "გაუშვი თითო მოქმედება ყველა ჩატვირთულ გვერდზე",
    "Version" : "ვერსია",
    "Sharing" : "გაზიარება",
    "Allow apps to use the Share API" : "დაუშვი აპლიკაციების უფლება  Share API –ზე",
    "Allow resharing" : "გადაზიარების დაშვება",
    "Forum" : "ფორუმი",
    "Cancel" : "უარყოფა",
    "Email" : "იმეილი",
    "Your email address" : "თქვენი იმეილ მისამართი",
    "Password" : "პაროლი",
    "Current password" : "მიმდინარე პაროლი",
    "New password" : "ახალი პაროლი",
    "Change password" : "პაროლის შეცვლა",
    "Language" : "ენა",
    "Help translate" : "თარგმნის დახმარება",
    "Get the apps to sync your files" : "აპლიკაცია ფაილების სინქრონიზაციისთვის",
    "Show First Run Wizard again" : "მაჩვენე თავიდან გაშვებული ვიზარდი",
    "Name" : "სახელი",
    "Username" : "მომხმარებლის სახელი",
    "Create" : "შექმნა",
    "Other" : "სხვა",
    "Quota" : "ქვოტა",
    "set new password" : "დააყენეთ ახალი პაროლი",
    "Default" : "საწყისი პარამეტრები",
    "Admins can't remove themself from the admin group" : "ადმინისტრატორებს არ შეუძლიათ საკუთარი თავის წაშლა ადმინ ჯგუფიდან",
    "Unable to add user to group %s" : "მომხმარებლის დამატება ვერ მოხეხდა ჯგუფში %s",
    "Unable to remove user from group %s" : "მომხმარებლის წაშლა ვერ მოხეხდა ჯგუფიდან %s",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP მოდული 'fileinfo' არ არსებობს. ჩვენ გირჩევთ რომ აუცილებლად ჩართოთ ეს მოდული, რომ მიიღოთ კარგი შედეგები mime-type–ს აღმოჩენისას."
},
"nplurals=1; plural=0;");

==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/settings/l10n/ka_GE.js <==
OC.L10N.register(
    "settings",
    {
    "Authentication error" : "ავთენტიფიკაციის შეცდომა",
    "Invalid request" : "არასწორი მოთხოვნა",
    "Email saved" : "იმეილი შენახულია",
    "Couldn't update app." : "ვერ მოხერხდა აპლიკაციის განახლება.",
    "Email sent" : "იმეილი გაიგზავნა",
    "All" : "ყველა",
    "Disable" : "გამორთვა",
    "Enable" : "ჩართვა",
    "Updating...." : "მიმდინარეობს განახლება....",
    "Error while updating app" : "შეცდომა აპლიკაციის განახლების დროს",
    "Updated" : "განახლებულია",
    "Delete" : "წაშლა",
    "Groups" : "ჯგუფები",
    "undo" : "დაბრუნება",
    "never" : "არასდროს",
    "A valid username must be provided" : "უნდა მიუთითოთ არსებული მომხმარებლის სახელი",
    "A valid password must be provided" : "უნდა მიუთითოთ არსებული პაროლი",
    "__language_name__" : "ქართული",
    "Unlimited" : "ულიმიტო",
    "None" : "არა",
    "Login" : "ლოგინი",
    "Encryption" : "ენკრიპცია",
    "Server address" : "სერვერის მისამართი",
    "Port" : "პორტი",
    "Credentials" : "იუზერ/პაროლი",
    "Execute one task with each page loaded" : "გაუშვი თითო მოქმედება ყველა ჩატვირთულ გვერდზე",
    "Version" : "ვერსია",
    "Sharing" : "გაზიარება",
    "Allow apps to use the Share API" : "დაუშვი აპლიკაციების უფლება  Share API –ზე",
    "Allow resharing" : "გადაზიარების დაშვება",
    "Forum" : "ფორუმი",
    "Cancel" : "უარყოფა",
    "Email" : "იმეილი",
    "Your email address" : "თქვენი იმეილ მისამართი",
    "Password" : "პაროლი",
    "Current password" : "მიმდინარე პაროლი",
    "New password" : "ახალი პაროლი",
    "Change password" : "პაროლის შეცვლა",
    "Language" : "ენა",
    "Help translate" : "თარგმნის დახმარება",
    "Get the apps to sync your files" : "აპლიკაცია ფაილების სინქრონიზაციისთვის",
    "Show First Run Wizard again" : "მაჩვენე თავიდან გაშვებული ვიზარდი",
    "Name" : "სახელი",
    "Username" : "მომხმარებლის სახელი",
    "Create" : "შექმნა",
    "Other" : "სხვა",
    "Quota" : "ქვოტა",
    "set new password" : "დააყენეთ ახალი პაროლი",
    "Default" : "საწყისი პარამეტრები",
    "Admins can't remove themself from the admin group" : "ადმინისტრატორებს არ შეუძლიათ საკუთარი თავის წაშლა ადმინ ჯგუფიდან",
    "Unable to add user to group %s" : "მომხმარებლის დამატება ვერ მოხეხდა ჯგუფში %s",
    "Unable to remove user from group %s" : "მომხმარებლის წაშლა ვერ მოხეხდა ჯგუფიდან %s",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP მოდული 'fileinfo' არ არსებობს. ჩვენ გირჩევთ რომ აუცილებლად ჩართოთ ეს მოდული, რომ მიიღოთ კარგი შედეგები mime-type–ს აღმოჩენისას.",
    "Cron" : "Cron–ი"
},
"nplurals=1; plural=0;");
